﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/appconfig/AppConfig_EXPORTS.h>
#include <aws/appconfig/AppConfigRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Http
{
    class URI;
} //namespace Http
namespace AppConfig
{
namespace Model
{

  /**
   */
  class ListApplicationsRequest : public AppConfigRequest
  {
  public:
    AWS_APPCONFIG_API ListApplicationsRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "ListApplications"; }

    AWS_APPCONFIG_API Aws::String SerializePayload() const override;

    AWS_APPCONFIG_API void AddQueryStringParameters(Aws::Http::URI& uri) const override;


    /**
     * <p>The maximum number of items to return for this call. The call also returns a
     * token that you can specify in a subsequent call to get the next set of
     * results.</p>
     */
    inline int GetMaxResults() const{ return m_maxResults; }

    /**
     * <p>The maximum number of items to return for this call. The call also returns a
     * token that you can specify in a subsequent call to get the next set of
     * results.</p>
     */
    inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }

    /**
     * <p>The maximum number of items to return for this call. The call also returns a
     * token that you can specify in a subsequent call to get the next set of
     * results.</p>
     */
    inline void SetMaxResults(int value) { m_maxResultsHasBeenSet = true; m_maxResults = value; }

    /**
     * <p>The maximum number of items to return for this call. The call also returns a
     * token that you can specify in a subsequent call to get the next set of
     * results.</p>
     */
    inline ListApplicationsRequest& WithMaxResults(int value) { SetMaxResults(value); return *this;}


    /**
     * <p>A token to start the list. Next token is a pagination token generated by
     * AppConfig to describe what page the previous List call ended on. For the first
     * List request, the nextToken should not be set. On subsequent calls, the
     * nextToken parameter should be set to the previous responses nextToken value. Use
     * this token to get the next set of results. </p>
     */
    inline const Aws::String& GetNextToken() const{ return m_nextToken; }

    /**
     * <p>A token to start the list. Next token is a pagination token generated by
     * AppConfig to describe what page the previous List call ended on. For the first
     * List request, the nextToken should not be set. On subsequent calls, the
     * nextToken parameter should be set to the previous responses nextToken value. Use
     * this token to get the next set of results. </p>
     */
    inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }

    /**
     * <p>A token to start the list. Next token is a pagination token generated by
     * AppConfig to describe what page the previous List call ended on. For the first
     * List request, the nextToken should not be set. On subsequent calls, the
     * nextToken parameter should be set to the previous responses nextToken value. Use
     * this token to get the next set of results. </p>
     */
    inline void SetNextToken(const Aws::String& value) { m_nextTokenHasBeenSet = true; m_nextToken = value; }

    /**
     * <p>A token to start the list. Next token is a pagination token generated by
     * AppConfig to describe what page the previous List call ended on. For the first
     * List request, the nextToken should not be set. On subsequent calls, the
     * nextToken parameter should be set to the previous responses nextToken value. Use
     * this token to get the next set of results. </p>
     */
    inline void SetNextToken(Aws::String&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::move(value); }

    /**
     * <p>A token to start the list. Next token is a pagination token generated by
     * AppConfig to describe what page the previous List call ended on. For the first
     * List request, the nextToken should not be set. On subsequent calls, the
     * nextToken parameter should be set to the previous responses nextToken value. Use
     * this token to get the next set of results. </p>
     */
    inline void SetNextToken(const char* value) { m_nextTokenHasBeenSet = true; m_nextToken.assign(value); }

    /**
     * <p>A token to start the list. Next token is a pagination token generated by
     * AppConfig to describe what page the previous List call ended on. For the first
     * List request, the nextToken should not be set. On subsequent calls, the
     * nextToken parameter should be set to the previous responses nextToken value. Use
     * this token to get the next set of results. </p>
     */
    inline ListApplicationsRequest& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}

    /**
     * <p>A token to start the list. Next token is a pagination token generated by
     * AppConfig to describe what page the previous List call ended on. For the first
     * List request, the nextToken should not be set. On subsequent calls, the
     * nextToken parameter should be set to the previous responses nextToken value. Use
     * this token to get the next set of results. </p>
     */
    inline ListApplicationsRequest& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}

    /**
     * <p>A token to start the list. Next token is a pagination token generated by
     * AppConfig to describe what page the previous List call ended on. For the first
     * List request, the nextToken should not be set. On subsequent calls, the
     * nextToken parameter should be set to the previous responses nextToken value. Use
     * this token to get the next set of results. </p>
     */
    inline ListApplicationsRequest& WithNextToken(const char* value) { SetNextToken(value); return *this;}

  private:

    int m_maxResults;
    bool m_maxResultsHasBeenSet = false;

    Aws::String m_nextToken;
    bool m_nextTokenHasBeenSet = false;
  };

} // namespace Model
} // namespace AppConfig
} // namespace Aws
