﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/appsync/AppSync_EXPORTS.h>
#include <aws/appsync/AppSyncRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/appsync/model/SourceApiAssociationConfig.h>
#include <utility>

namespace Aws
{
namespace AppSync
{
namespace Model
{

  /**
   */
  class AssociateMergedGraphqlApiRequest : public AppSyncRequest
  {
  public:
    AWS_APPSYNC_API AssociateMergedGraphqlApiRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "AssociateMergedGraphqlApi"; }

    AWS_APPSYNC_API Aws::String SerializePayload() const override;


    /**
     * <p>The identifier of the AppSync Source API. This is generated by the AppSync
     * service. In most cases, source APIs (especially in your account) only require
     * the API ID value or ARN of the source API. However, source APIs from other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * source API.</p>
     */
    inline const Aws::String& GetSourceApiIdentifier() const{ return m_sourceApiIdentifier; }

    /**
     * <p>The identifier of the AppSync Source API. This is generated by the AppSync
     * service. In most cases, source APIs (especially in your account) only require
     * the API ID value or ARN of the source API. However, source APIs from other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * source API.</p>
     */
    inline bool SourceApiIdentifierHasBeenSet() const { return m_sourceApiIdentifierHasBeenSet; }

    /**
     * <p>The identifier of the AppSync Source API. This is generated by the AppSync
     * service. In most cases, source APIs (especially in your account) only require
     * the API ID value or ARN of the source API. However, source APIs from other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * source API.</p>
     */
    inline void SetSourceApiIdentifier(const Aws::String& value) { m_sourceApiIdentifierHasBeenSet = true; m_sourceApiIdentifier = value; }

    /**
     * <p>The identifier of the AppSync Source API. This is generated by the AppSync
     * service. In most cases, source APIs (especially in your account) only require
     * the API ID value or ARN of the source API. However, source APIs from other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * source API.</p>
     */
    inline void SetSourceApiIdentifier(Aws::String&& value) { m_sourceApiIdentifierHasBeenSet = true; m_sourceApiIdentifier = std::move(value); }

    /**
     * <p>The identifier of the AppSync Source API. This is generated by the AppSync
     * service. In most cases, source APIs (especially in your account) only require
     * the API ID value or ARN of the source API. However, source APIs from other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * source API.</p>
     */
    inline void SetSourceApiIdentifier(const char* value) { m_sourceApiIdentifierHasBeenSet = true; m_sourceApiIdentifier.assign(value); }

    /**
     * <p>The identifier of the AppSync Source API. This is generated by the AppSync
     * service. In most cases, source APIs (especially in your account) only require
     * the API ID value or ARN of the source API. However, source APIs from other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * source API.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithSourceApiIdentifier(const Aws::String& value) { SetSourceApiIdentifier(value); return *this;}

    /**
     * <p>The identifier of the AppSync Source API. This is generated by the AppSync
     * service. In most cases, source APIs (especially in your account) only require
     * the API ID value or ARN of the source API. However, source APIs from other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * source API.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithSourceApiIdentifier(Aws::String&& value) { SetSourceApiIdentifier(std::move(value)); return *this;}

    /**
     * <p>The identifier of the AppSync Source API. This is generated by the AppSync
     * service. In most cases, source APIs (especially in your account) only require
     * the API ID value or ARN of the source API. However, source APIs from other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * source API.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithSourceApiIdentifier(const char* value) { SetSourceApiIdentifier(value); return *this;}


    /**
     * <p>The identifier of the AppSync Merged API. This is generated by the AppSync
     * service. In most cases, Merged APIs (especially in your account) only require
     * the API ID value or ARN of the merged API. However, Merged APIs in other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * merged API.</p>
     */
    inline const Aws::String& GetMergedApiIdentifier() const{ return m_mergedApiIdentifier; }

    /**
     * <p>The identifier of the AppSync Merged API. This is generated by the AppSync
     * service. In most cases, Merged APIs (especially in your account) only require
     * the API ID value or ARN of the merged API. However, Merged APIs in other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * merged API.</p>
     */
    inline bool MergedApiIdentifierHasBeenSet() const { return m_mergedApiIdentifierHasBeenSet; }

    /**
     * <p>The identifier of the AppSync Merged API. This is generated by the AppSync
     * service. In most cases, Merged APIs (especially in your account) only require
     * the API ID value or ARN of the merged API. However, Merged APIs in other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * merged API.</p>
     */
    inline void SetMergedApiIdentifier(const Aws::String& value) { m_mergedApiIdentifierHasBeenSet = true; m_mergedApiIdentifier = value; }

    /**
     * <p>The identifier of the AppSync Merged API. This is generated by the AppSync
     * service. In most cases, Merged APIs (especially in your account) only require
     * the API ID value or ARN of the merged API. However, Merged APIs in other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * merged API.</p>
     */
    inline void SetMergedApiIdentifier(Aws::String&& value) { m_mergedApiIdentifierHasBeenSet = true; m_mergedApiIdentifier = std::move(value); }

    /**
     * <p>The identifier of the AppSync Merged API. This is generated by the AppSync
     * service. In most cases, Merged APIs (especially in your account) only require
     * the API ID value or ARN of the merged API. However, Merged APIs in other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * merged API.</p>
     */
    inline void SetMergedApiIdentifier(const char* value) { m_mergedApiIdentifierHasBeenSet = true; m_mergedApiIdentifier.assign(value); }

    /**
     * <p>The identifier of the AppSync Merged API. This is generated by the AppSync
     * service. In most cases, Merged APIs (especially in your account) only require
     * the API ID value or ARN of the merged API. However, Merged APIs in other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * merged API.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithMergedApiIdentifier(const Aws::String& value) { SetMergedApiIdentifier(value); return *this;}

    /**
     * <p>The identifier of the AppSync Merged API. This is generated by the AppSync
     * service. In most cases, Merged APIs (especially in your account) only require
     * the API ID value or ARN of the merged API. However, Merged APIs in other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * merged API.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithMergedApiIdentifier(Aws::String&& value) { SetMergedApiIdentifier(std::move(value)); return *this;}

    /**
     * <p>The identifier of the AppSync Merged API. This is generated by the AppSync
     * service. In most cases, Merged APIs (especially in your account) only require
     * the API ID value or ARN of the merged API. However, Merged APIs in other
     * accounts (cross-account use cases) strictly require the full resource ARN of the
     * merged API.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithMergedApiIdentifier(const char* value) { SetMergedApiIdentifier(value); return *this;}


    /**
     * <p>The description field.</p>
     */
    inline const Aws::String& GetDescription() const{ return m_description; }

    /**
     * <p>The description field.</p>
     */
    inline bool DescriptionHasBeenSet() const { return m_descriptionHasBeenSet; }

    /**
     * <p>The description field.</p>
     */
    inline void SetDescription(const Aws::String& value) { m_descriptionHasBeenSet = true; m_description = value; }

    /**
     * <p>The description field.</p>
     */
    inline void SetDescription(Aws::String&& value) { m_descriptionHasBeenSet = true; m_description = std::move(value); }

    /**
     * <p>The description field.</p>
     */
    inline void SetDescription(const char* value) { m_descriptionHasBeenSet = true; m_description.assign(value); }

    /**
     * <p>The description field.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithDescription(const Aws::String& value) { SetDescription(value); return *this;}

    /**
     * <p>The description field.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithDescription(Aws::String&& value) { SetDescription(std::move(value)); return *this;}

    /**
     * <p>The description field.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithDescription(const char* value) { SetDescription(value); return *this;}


    /**
     * <p>The <code>SourceApiAssociationConfig</code> object data.</p>
     */
    inline const SourceApiAssociationConfig& GetSourceApiAssociationConfig() const{ return m_sourceApiAssociationConfig; }

    /**
     * <p>The <code>SourceApiAssociationConfig</code> object data.</p>
     */
    inline bool SourceApiAssociationConfigHasBeenSet() const { return m_sourceApiAssociationConfigHasBeenSet; }

    /**
     * <p>The <code>SourceApiAssociationConfig</code> object data.</p>
     */
    inline void SetSourceApiAssociationConfig(const SourceApiAssociationConfig& value) { m_sourceApiAssociationConfigHasBeenSet = true; m_sourceApiAssociationConfig = value; }

    /**
     * <p>The <code>SourceApiAssociationConfig</code> object data.</p>
     */
    inline void SetSourceApiAssociationConfig(SourceApiAssociationConfig&& value) { m_sourceApiAssociationConfigHasBeenSet = true; m_sourceApiAssociationConfig = std::move(value); }

    /**
     * <p>The <code>SourceApiAssociationConfig</code> object data.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithSourceApiAssociationConfig(const SourceApiAssociationConfig& value) { SetSourceApiAssociationConfig(value); return *this;}

    /**
     * <p>The <code>SourceApiAssociationConfig</code> object data.</p>
     */
    inline AssociateMergedGraphqlApiRequest& WithSourceApiAssociationConfig(SourceApiAssociationConfig&& value) { SetSourceApiAssociationConfig(std::move(value)); return *this;}

  private:

    Aws::String m_sourceApiIdentifier;
    bool m_sourceApiIdentifierHasBeenSet = false;

    Aws::String m_mergedApiIdentifier;
    bool m_mergedApiIdentifierHasBeenSet = false;

    Aws::String m_description;
    bool m_descriptionHasBeenSet = false;

    SourceApiAssociationConfig m_sourceApiAssociationConfig;
    bool m_sourceApiAssociationConfigHasBeenSet = false;
  };

} // namespace Model
} // namespace AppSync
} // namespace Aws
