﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/backup/Backup_EXPORTS.h>
#include <aws/backup/BackupRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Backup
{
namespace Model
{

  /**
   */
  class DisassociateRecoveryPointFromParentRequest : public BackupRequest
  {
  public:
    AWS_BACKUP_API DisassociateRecoveryPointFromParentRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "DisassociateRecoveryPointFromParent"; }

    AWS_BACKUP_API Aws::String SerializePayload() const override;


    /**
     * <p>This is the name of a logical container where the child (nested) recovery
     * point is stored. Backup vaults are identified by names that are unique to the
     * account used to create them and the Amazon Web Services Region where they are
     * created. They consist of lowercase letters, numbers, and hyphens.</p>
     */
    inline const Aws::String& GetBackupVaultName() const{ return m_backupVaultName; }

    /**
     * <p>This is the name of a logical container where the child (nested) recovery
     * point is stored. Backup vaults are identified by names that are unique to the
     * account used to create them and the Amazon Web Services Region where they are
     * created. They consist of lowercase letters, numbers, and hyphens.</p>
     */
    inline bool BackupVaultNameHasBeenSet() const { return m_backupVaultNameHasBeenSet; }

    /**
     * <p>This is the name of a logical container where the child (nested) recovery
     * point is stored. Backup vaults are identified by names that are unique to the
     * account used to create them and the Amazon Web Services Region where they are
     * created. They consist of lowercase letters, numbers, and hyphens.</p>
     */
    inline void SetBackupVaultName(const Aws::String& value) { m_backupVaultNameHasBeenSet = true; m_backupVaultName = value; }

    /**
     * <p>This is the name of a logical container where the child (nested) recovery
     * point is stored. Backup vaults are identified by names that are unique to the
     * account used to create them and the Amazon Web Services Region where they are
     * created. They consist of lowercase letters, numbers, and hyphens.</p>
     */
    inline void SetBackupVaultName(Aws::String&& value) { m_backupVaultNameHasBeenSet = true; m_backupVaultName = std::move(value); }

    /**
     * <p>This is the name of a logical container where the child (nested) recovery
     * point is stored. Backup vaults are identified by names that are unique to the
     * account used to create them and the Amazon Web Services Region where they are
     * created. They consist of lowercase letters, numbers, and hyphens.</p>
     */
    inline void SetBackupVaultName(const char* value) { m_backupVaultNameHasBeenSet = true; m_backupVaultName.assign(value); }

    /**
     * <p>This is the name of a logical container where the child (nested) recovery
     * point is stored. Backup vaults are identified by names that are unique to the
     * account used to create them and the Amazon Web Services Region where they are
     * created. They consist of lowercase letters, numbers, and hyphens.</p>
     */
    inline DisassociateRecoveryPointFromParentRequest& WithBackupVaultName(const Aws::String& value) { SetBackupVaultName(value); return *this;}

    /**
     * <p>This is the name of a logical container where the child (nested) recovery
     * point is stored. Backup vaults are identified by names that are unique to the
     * account used to create them and the Amazon Web Services Region where they are
     * created. They consist of lowercase letters, numbers, and hyphens.</p>
     */
    inline DisassociateRecoveryPointFromParentRequest& WithBackupVaultName(Aws::String&& value) { SetBackupVaultName(std::move(value)); return *this;}

    /**
     * <p>This is the name of a logical container where the child (nested) recovery
     * point is stored. Backup vaults are identified by names that are unique to the
     * account used to create them and the Amazon Web Services Region where they are
     * created. They consist of lowercase letters, numbers, and hyphens.</p>
     */
    inline DisassociateRecoveryPointFromParentRequest& WithBackupVaultName(const char* value) { SetBackupVaultName(value); return *this;}


    /**
     * <p>This is the Amazon Resource Name (ARN) that uniquely identifies the child
     * (nested) recovery point; for example,
     * <code>arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.</code>
     * </p>
     */
    inline const Aws::String& GetRecoveryPointArn() const{ return m_recoveryPointArn; }

    /**
     * <p>This is the Amazon Resource Name (ARN) that uniquely identifies the child
     * (nested) recovery point; for example,
     * <code>arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.</code>
     * </p>
     */
    inline bool RecoveryPointArnHasBeenSet() const { return m_recoveryPointArnHasBeenSet; }

    /**
     * <p>This is the Amazon Resource Name (ARN) that uniquely identifies the child
     * (nested) recovery point; for example,
     * <code>arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.</code>
     * </p>
     */
    inline void SetRecoveryPointArn(const Aws::String& value) { m_recoveryPointArnHasBeenSet = true; m_recoveryPointArn = value; }

    /**
     * <p>This is the Amazon Resource Name (ARN) that uniquely identifies the child
     * (nested) recovery point; for example,
     * <code>arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.</code>
     * </p>
     */
    inline void SetRecoveryPointArn(Aws::String&& value) { m_recoveryPointArnHasBeenSet = true; m_recoveryPointArn = std::move(value); }

    /**
     * <p>This is the Amazon Resource Name (ARN) that uniquely identifies the child
     * (nested) recovery point; for example,
     * <code>arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.</code>
     * </p>
     */
    inline void SetRecoveryPointArn(const char* value) { m_recoveryPointArnHasBeenSet = true; m_recoveryPointArn.assign(value); }

    /**
     * <p>This is the Amazon Resource Name (ARN) that uniquely identifies the child
     * (nested) recovery point; for example,
     * <code>arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.</code>
     * </p>
     */
    inline DisassociateRecoveryPointFromParentRequest& WithRecoveryPointArn(const Aws::String& value) { SetRecoveryPointArn(value); return *this;}

    /**
     * <p>This is the Amazon Resource Name (ARN) that uniquely identifies the child
     * (nested) recovery point; for example,
     * <code>arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.</code>
     * </p>
     */
    inline DisassociateRecoveryPointFromParentRequest& WithRecoveryPointArn(Aws::String&& value) { SetRecoveryPointArn(std::move(value)); return *this;}

    /**
     * <p>This is the Amazon Resource Name (ARN) that uniquely identifies the child
     * (nested) recovery point; for example,
     * <code>arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.</code>
     * </p>
     */
    inline DisassociateRecoveryPointFromParentRequest& WithRecoveryPointArn(const char* value) { SetRecoveryPointArn(value); return *this;}

  private:

    Aws::String m_backupVaultName;
    bool m_backupVaultNameHasBeenSet = false;

    Aws::String m_recoveryPointArn;
    bool m_recoveryPointArnHasBeenSet = false;
  };

} // namespace Model
} // namespace Backup
} // namespace Aws
