﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/discovery/ApplicationDiscoveryService_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/discovery/model/AgentInfo.h>
#include <utility>

namespace Aws
{
template<typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils
{
namespace Json
{
  class JsonValue;
} // namespace Json
} // namespace Utils
namespace ApplicationDiscoveryService
{
namespace Model
{
  class DescribeAgentsResult
  {
  public:
    AWS_APPLICATIONDISCOVERYSERVICE_API DescribeAgentsResult();
    AWS_APPLICATIONDISCOVERYSERVICE_API DescribeAgentsResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
    AWS_APPLICATIONDISCOVERYSERVICE_API DescribeAgentsResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);


    /**
     * <p>Lists agents or the collector by ID or lists all agents/collectors associated
     * with your user, if you did not specify an agent/collector ID. The output
     * includes agent/collector IDs, IP addresses, media access control (MAC)
     * addresses, agent/collector health, host name where the agent/collector resides,
     * and the version number of each agent/collector.</p>
     */
    inline const Aws::Vector<AgentInfo>& GetAgentsInfo() const{ return m_agentsInfo; }

    /**
     * <p>Lists agents or the collector by ID or lists all agents/collectors associated
     * with your user, if you did not specify an agent/collector ID. The output
     * includes agent/collector IDs, IP addresses, media access control (MAC)
     * addresses, agent/collector health, host name where the agent/collector resides,
     * and the version number of each agent/collector.</p>
     */
    inline void SetAgentsInfo(const Aws::Vector<AgentInfo>& value) { m_agentsInfo = value; }

    /**
     * <p>Lists agents or the collector by ID or lists all agents/collectors associated
     * with your user, if you did not specify an agent/collector ID. The output
     * includes agent/collector IDs, IP addresses, media access control (MAC)
     * addresses, agent/collector health, host name where the agent/collector resides,
     * and the version number of each agent/collector.</p>
     */
    inline void SetAgentsInfo(Aws::Vector<AgentInfo>&& value) { m_agentsInfo = std::move(value); }

    /**
     * <p>Lists agents or the collector by ID or lists all agents/collectors associated
     * with your user, if you did not specify an agent/collector ID. The output
     * includes agent/collector IDs, IP addresses, media access control (MAC)
     * addresses, agent/collector health, host name where the agent/collector resides,
     * and the version number of each agent/collector.</p>
     */
    inline DescribeAgentsResult& WithAgentsInfo(const Aws::Vector<AgentInfo>& value) { SetAgentsInfo(value); return *this;}

    /**
     * <p>Lists agents or the collector by ID or lists all agents/collectors associated
     * with your user, if you did not specify an agent/collector ID. The output
     * includes agent/collector IDs, IP addresses, media access control (MAC)
     * addresses, agent/collector health, host name where the agent/collector resides,
     * and the version number of each agent/collector.</p>
     */
    inline DescribeAgentsResult& WithAgentsInfo(Aws::Vector<AgentInfo>&& value) { SetAgentsInfo(std::move(value)); return *this;}

    /**
     * <p>Lists agents or the collector by ID or lists all agents/collectors associated
     * with your user, if you did not specify an agent/collector ID. The output
     * includes agent/collector IDs, IP addresses, media access control (MAC)
     * addresses, agent/collector health, host name where the agent/collector resides,
     * and the version number of each agent/collector.</p>
     */
    inline DescribeAgentsResult& AddAgentsInfo(const AgentInfo& value) { m_agentsInfo.push_back(value); return *this; }

    /**
     * <p>Lists agents or the collector by ID or lists all agents/collectors associated
     * with your user, if you did not specify an agent/collector ID. The output
     * includes agent/collector IDs, IP addresses, media access control (MAC)
     * addresses, agent/collector health, host name where the agent/collector resides,
     * and the version number of each agent/collector.</p>
     */
    inline DescribeAgentsResult& AddAgentsInfo(AgentInfo&& value) { m_agentsInfo.push_back(std::move(value)); return *this; }


    /**
     * <p>Token to retrieve the next set of results. For example, if you specified 100
     * IDs for <code>DescribeAgentsRequest$agentIds</code> but set
     * <code>DescribeAgentsRequest$maxResults</code> to 10, you received a set of 10
     * results along with this token. Use this token in the next query to retrieve the
     * next set of 10.</p>
     */
    inline const Aws::String& GetNextToken() const{ return m_nextToken; }

    /**
     * <p>Token to retrieve the next set of results. For example, if you specified 100
     * IDs for <code>DescribeAgentsRequest$agentIds</code> but set
     * <code>DescribeAgentsRequest$maxResults</code> to 10, you received a set of 10
     * results along with this token. Use this token in the next query to retrieve the
     * next set of 10.</p>
     */
    inline void SetNextToken(const Aws::String& value) { m_nextToken = value; }

    /**
     * <p>Token to retrieve the next set of results. For example, if you specified 100
     * IDs for <code>DescribeAgentsRequest$agentIds</code> but set
     * <code>DescribeAgentsRequest$maxResults</code> to 10, you received a set of 10
     * results along with this token. Use this token in the next query to retrieve the
     * next set of 10.</p>
     */
    inline void SetNextToken(Aws::String&& value) { m_nextToken = std::move(value); }

    /**
     * <p>Token to retrieve the next set of results. For example, if you specified 100
     * IDs for <code>DescribeAgentsRequest$agentIds</code> but set
     * <code>DescribeAgentsRequest$maxResults</code> to 10, you received a set of 10
     * results along with this token. Use this token in the next query to retrieve the
     * next set of 10.</p>
     */
    inline void SetNextToken(const char* value) { m_nextToken.assign(value); }

    /**
     * <p>Token to retrieve the next set of results. For example, if you specified 100
     * IDs for <code>DescribeAgentsRequest$agentIds</code> but set
     * <code>DescribeAgentsRequest$maxResults</code> to 10, you received a set of 10
     * results along with this token. Use this token in the next query to retrieve the
     * next set of 10.</p>
     */
    inline DescribeAgentsResult& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}

    /**
     * <p>Token to retrieve the next set of results. For example, if you specified 100
     * IDs for <code>DescribeAgentsRequest$agentIds</code> but set
     * <code>DescribeAgentsRequest$maxResults</code> to 10, you received a set of 10
     * results along with this token. Use this token in the next query to retrieve the
     * next set of 10.</p>
     */
    inline DescribeAgentsResult& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}

    /**
     * <p>Token to retrieve the next set of results. For example, if you specified 100
     * IDs for <code>DescribeAgentsRequest$agentIds</code> but set
     * <code>DescribeAgentsRequest$maxResults</code> to 10, you received a set of 10
     * results along with this token. Use this token in the next query to retrieve the
     * next set of 10.</p>
     */
    inline DescribeAgentsResult& WithNextToken(const char* value) { SetNextToken(value); return *this;}


    
    inline const Aws::String& GetRequestId() const{ return m_requestId; }

    
    inline void SetRequestId(const Aws::String& value) { m_requestId = value; }

    
    inline void SetRequestId(Aws::String&& value) { m_requestId = std::move(value); }

    
    inline void SetRequestId(const char* value) { m_requestId.assign(value); }

    
    inline DescribeAgentsResult& WithRequestId(const Aws::String& value) { SetRequestId(value); return *this;}

    
    inline DescribeAgentsResult& WithRequestId(Aws::String&& value) { SetRequestId(std::move(value)); return *this;}

    
    inline DescribeAgentsResult& WithRequestId(const char* value) { SetRequestId(value); return *this;}

  private:

    Aws::Vector<AgentInfo> m_agentsInfo;

    Aws::String m_nextToken;

    Aws::String m_requestId;
  };

} // namespace Model
} // namespace ApplicationDiscoveryService
} // namespace Aws
