﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/drs/Drs_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/drs/model/SourceNetwork.h>
#include <utility>

namespace Aws
{
template<typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils
{
namespace Json
{
  class JsonValue;
} // namespace Json
} // namespace Utils
namespace drs
{
namespace Model
{
  class DescribeSourceNetworksResult
  {
  public:
    AWS_DRS_API DescribeSourceNetworksResult();
    AWS_DRS_API DescribeSourceNetworksResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
    AWS_DRS_API DescribeSourceNetworksResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);


    /**
     * <p>An array of Source Networks.</p>
     */
    inline const Aws::Vector<SourceNetwork>& GetItems() const{ return m_items; }

    /**
     * <p>An array of Source Networks.</p>
     */
    inline void SetItems(const Aws::Vector<SourceNetwork>& value) { m_items = value; }

    /**
     * <p>An array of Source Networks.</p>
     */
    inline void SetItems(Aws::Vector<SourceNetwork>&& value) { m_items = std::move(value); }

    /**
     * <p>An array of Source Networks.</p>
     */
    inline DescribeSourceNetworksResult& WithItems(const Aws::Vector<SourceNetwork>& value) { SetItems(value); return *this;}

    /**
     * <p>An array of Source Networks.</p>
     */
    inline DescribeSourceNetworksResult& WithItems(Aws::Vector<SourceNetwork>&& value) { SetItems(std::move(value)); return *this;}

    /**
     * <p>An array of Source Networks.</p>
     */
    inline DescribeSourceNetworksResult& AddItems(const SourceNetwork& value) { m_items.push_back(value); return *this; }

    /**
     * <p>An array of Source Networks.</p>
     */
    inline DescribeSourceNetworksResult& AddItems(SourceNetwork&& value) { m_items.push_back(std::move(value)); return *this; }


    /**
     * <p>The token of the next Source Networks to retrieve.</p>
     */
    inline const Aws::String& GetNextToken() const{ return m_nextToken; }

    /**
     * <p>The token of the next Source Networks to retrieve.</p>
     */
    inline void SetNextToken(const Aws::String& value) { m_nextToken = value; }

    /**
     * <p>The token of the next Source Networks to retrieve.</p>
     */
    inline void SetNextToken(Aws::String&& value) { m_nextToken = std::move(value); }

    /**
     * <p>The token of the next Source Networks to retrieve.</p>
     */
    inline void SetNextToken(const char* value) { m_nextToken.assign(value); }

    /**
     * <p>The token of the next Source Networks to retrieve.</p>
     */
    inline DescribeSourceNetworksResult& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}

    /**
     * <p>The token of the next Source Networks to retrieve.</p>
     */
    inline DescribeSourceNetworksResult& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}

    /**
     * <p>The token of the next Source Networks to retrieve.</p>
     */
    inline DescribeSourceNetworksResult& WithNextToken(const char* value) { SetNextToken(value); return *this;}


    
    inline const Aws::String& GetRequestId() const{ return m_requestId; }

    
    inline void SetRequestId(const Aws::String& value) { m_requestId = value; }

    
    inline void SetRequestId(Aws::String&& value) { m_requestId = std::move(value); }

    
    inline void SetRequestId(const char* value) { m_requestId.assign(value); }

    
    inline DescribeSourceNetworksResult& WithRequestId(const Aws::String& value) { SetRequestId(value); return *this;}

    
    inline DescribeSourceNetworksResult& WithRequestId(Aws::String&& value) { SetRequestId(std::move(value)); return *this;}

    
    inline DescribeSourceNetworksResult& WithRequestId(const char* value) { SetRequestId(value); return *this;}

  private:

    Aws::Vector<SourceNetwork> m_items;

    Aws::String m_nextToken;

    Aws::String m_requestId;
  };

} // namespace Model
} // namespace drs
} // namespace Aws
