﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/ec2/EC2_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/ec2/model/ResponseMetadata.h>
#include <aws/ec2/model/ClientVpnConnection.h>
#include <utility>

namespace Aws
{
template<typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils
{
namespace Xml
{
  class XmlDocument;
} // namespace Xml
} // namespace Utils
namespace EC2
{
namespace Model
{
  class DescribeClientVpnConnectionsResponse
  {
  public:
    AWS_EC2_API DescribeClientVpnConnectionsResponse();
    AWS_EC2_API DescribeClientVpnConnectionsResponse(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);
    AWS_EC2_API DescribeClientVpnConnectionsResponse& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);


    /**
     * <p>Information about the active and terminated client connections.</p>
     */
    inline const Aws::Vector<ClientVpnConnection>& GetConnections() const{ return m_connections; }

    /**
     * <p>Information about the active and terminated client connections.</p>
     */
    inline void SetConnections(const Aws::Vector<ClientVpnConnection>& value) { m_connections = value; }

    /**
     * <p>Information about the active and terminated client connections.</p>
     */
    inline void SetConnections(Aws::Vector<ClientVpnConnection>&& value) { m_connections = std::move(value); }

    /**
     * <p>Information about the active and terminated client connections.</p>
     */
    inline DescribeClientVpnConnectionsResponse& WithConnections(const Aws::Vector<ClientVpnConnection>& value) { SetConnections(value); return *this;}

    /**
     * <p>Information about the active and terminated client connections.</p>
     */
    inline DescribeClientVpnConnectionsResponse& WithConnections(Aws::Vector<ClientVpnConnection>&& value) { SetConnections(std::move(value)); return *this;}

    /**
     * <p>Information about the active and terminated client connections.</p>
     */
    inline DescribeClientVpnConnectionsResponse& AddConnections(const ClientVpnConnection& value) { m_connections.push_back(value); return *this; }

    /**
     * <p>Information about the active and terminated client connections.</p>
     */
    inline DescribeClientVpnConnectionsResponse& AddConnections(ClientVpnConnection&& value) { m_connections.push_back(std::move(value)); return *this; }


    /**
     * <p>The token to use to retrieve the next page of results. This value is
     * <code>null</code> when there are no more results to return.</p>
     */
    inline const Aws::String& GetNextToken() const{ return m_nextToken; }

    /**
     * <p>The token to use to retrieve the next page of results. This value is
     * <code>null</code> when there are no more results to return.</p>
     */
    inline void SetNextToken(const Aws::String& value) { m_nextToken = value; }

    /**
     * <p>The token to use to retrieve the next page of results. This value is
     * <code>null</code> when there are no more results to return.</p>
     */
    inline void SetNextToken(Aws::String&& value) { m_nextToken = std::move(value); }

    /**
     * <p>The token to use to retrieve the next page of results. This value is
     * <code>null</code> when there are no more results to return.</p>
     */
    inline void SetNextToken(const char* value) { m_nextToken.assign(value); }

    /**
     * <p>The token to use to retrieve the next page of results. This value is
     * <code>null</code> when there are no more results to return.</p>
     */
    inline DescribeClientVpnConnectionsResponse& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}

    /**
     * <p>The token to use to retrieve the next page of results. This value is
     * <code>null</code> when there are no more results to return.</p>
     */
    inline DescribeClientVpnConnectionsResponse& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}

    /**
     * <p>The token to use to retrieve the next page of results. This value is
     * <code>null</code> when there are no more results to return.</p>
     */
    inline DescribeClientVpnConnectionsResponse& WithNextToken(const char* value) { SetNextToken(value); return *this;}


    
    inline const ResponseMetadata& GetResponseMetadata() const{ return m_responseMetadata; }

    
    inline void SetResponseMetadata(const ResponseMetadata& value) { m_responseMetadata = value; }

    
    inline void SetResponseMetadata(ResponseMetadata&& value) { m_responseMetadata = std::move(value); }

    
    inline DescribeClientVpnConnectionsResponse& WithResponseMetadata(const ResponseMetadata& value) { SetResponseMetadata(value); return *this;}

    
    inline DescribeClientVpnConnectionsResponse& WithResponseMetadata(ResponseMetadata&& value) { SetResponseMetadata(std::move(value)); return *this;}

  private:

    Aws::Vector<ClientVpnConnection> m_connections;

    Aws::String m_nextToken;

    ResponseMetadata m_responseMetadata;
  };

} // namespace Model
} // namespace EC2
} // namespace Aws
