﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/ec2/EC2_EXPORTS.h>
#include <aws/ec2/EC2Request.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/ec2/model/Filter.h>
#include <utility>

namespace Aws
{
namespace EC2
{
namespace Model
{

  /**
   */
  class DescribeVolumesRequest : public EC2Request
  {
  public:
    AWS_EC2_API DescribeVolumesRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "DescribeVolumes"; }

    AWS_EC2_API Aws::String SerializePayload() const override;

  protected:
    AWS_EC2_API void DumpBodyToUrl(Aws::Http::URI& uri ) const override;

  public:

    /**
     * <p>The filters.</p> <ul> <li> <p> <code>attachment.attach-time</code> - The time
     * stamp when the attachment initiated.</p> </li> <li> <p>
     * <code>attachment.delete-on-termination</code> - Whether the volume is deleted on
     * instance termination.</p> </li> <li> <p> <code>attachment.device</code> - The
     * device name specified in the block device mapping (for example,
     * <code>/dev/sda1</code>).</p> </li> <li> <p> <code>attachment.instance-id</code>
     * - The ID of the instance the volume is attached to.</p> </li> <li> <p>
     * <code>attachment.status</code> - The attachment state (<code>attaching</code> |
     * <code>attached</code> | <code>detaching</code>).</p> </li> <li> <p>
     * <code>availability-zone</code> - The Availability Zone in which the volume was
     * created.</p> </li> <li> <p> <code>create-time</code> - The time stamp when the
     * volume was created.</p> </li> <li> <p> <code>encrypted</code> - Indicates
     * whether the volume is encrypted (<code>true</code> | <code>false</code>)</p>
     * </li> <li> <p> <code>multi-attach-enabled</code> - Indicates whether the volume
     * is enabled for Multi-Attach (<code>true</code> | <code>false</code>)</p> </li>
     * <li> <p> <code>fast-restored</code> - Indicates whether the volume was created
     * from a snapshot that is enabled for fast snapshot restore (<code>true</code> |
     * <code>false</code>).</p> </li> <li> <p> <code>size</code> - The size of the
     * volume, in GiB.</p> </li> <li> <p> <code>snapshot-id</code> - The snapshot from
     * which the volume was created.</p> </li> <li> <p> <code>status</code> - The state
     * of the volume (<code>creating</code> | <code>available</code> |
     * <code>in-use</code> | <code>deleting</code> | <code>deleted</code> |
     * <code>error</code>).</p> </li> <li> <p> <code>tag</code>:&lt;key&gt; - The
     * key/value combination of a tag assigned to the resource. Use the tag key in the
     * filter name and the tag value as the filter value. For example, to find all
     * resources that have a tag with the key <code>Owner</code> and the value
     * <code>TeamA</code>, specify <code>tag:Owner</code> for the filter name and
     * <code>TeamA</code> for the filter value.</p> </li> <li> <p> <code>tag-key</code>
     * - The key of a tag assigned to the resource. Use this filter to find all
     * resources assigned a tag with a specific key, regardless of the tag value.</p>
     * </li> <li> <p> <code>volume-id</code> - The volume ID.</p> </li> <li> <p>
     * <code>volume-type</code> - The Amazon EBS volume type (<code>gp2</code> |
     * <code>gp3</code> | <code>io1</code> | <code>io2</code> | <code>st1</code> |
     * <code>sc1</code>| <code>standard</code>)</p> </li> </ul>
     */
    inline const Aws::Vector<Filter>& GetFilters() const{ return m_filters; }

    /**
     * <p>The filters.</p> <ul> <li> <p> <code>attachment.attach-time</code> - The time
     * stamp when the attachment initiated.</p> </li> <li> <p>
     * <code>attachment.delete-on-termination</code> - Whether the volume is deleted on
     * instance termination.</p> </li> <li> <p> <code>attachment.device</code> - The
     * device name specified in the block device mapping (for example,
     * <code>/dev/sda1</code>).</p> </li> <li> <p> <code>attachment.instance-id</code>
     * - The ID of the instance the volume is attached to.</p> </li> <li> <p>
     * <code>attachment.status</code> - The attachment state (<code>attaching</code> |
     * <code>attached</code> | <code>detaching</code>).</p> </li> <li> <p>
     * <code>availability-zone</code> - The Availability Zone in which the volume was
     * created.</p> </li> <li> <p> <code>create-time</code> - The time stamp when the
     * volume was created.</p> </li> <li> <p> <code>encrypted</code> - Indicates
     * whether the volume is encrypted (<code>true</code> | <code>false</code>)</p>
     * </li> <li> <p> <code>multi-attach-enabled</code> - Indicates whether the volume
     * is enabled for Multi-Attach (<code>true</code> | <code>false</code>)</p> </li>
     * <li> <p> <code>fast-restored</code> - Indicates whether the volume was created
     * from a snapshot that is enabled for fast snapshot restore (<code>true</code> |
     * <code>false</code>).</p> </li> <li> <p> <code>size</code> - The size of the
     * volume, in GiB.</p> </li> <li> <p> <code>snapshot-id</code> - The snapshot from
     * which the volume was created.</p> </li> <li> <p> <code>status</code> - The state
     * of the volume (<code>creating</code> | <code>available</code> |
     * <code>in-use</code> | <code>deleting</code> | <code>deleted</code> |
     * <code>error</code>).</p> </li> <li> <p> <code>tag</code>:&lt;key&gt; - The
     * key/value combination of a tag assigned to the resource. Use the tag key in the
     * filter name and the tag value as the filter value. For example, to find all
     * resources that have a tag with the key <code>Owner</code> and the value
     * <code>TeamA</code>, specify <code>tag:Owner</code> for the filter name and
     * <code>TeamA</code> for the filter value.</p> </li> <li> <p> <code>tag-key</code>
     * - The key of a tag assigned to the resource. Use this filter to find all
     * resources assigned a tag with a specific key, regardless of the tag value.</p>
     * </li> <li> <p> <code>volume-id</code> - The volume ID.</p> </li> <li> <p>
     * <code>volume-type</code> - The Amazon EBS volume type (<code>gp2</code> |
     * <code>gp3</code> | <code>io1</code> | <code>io2</code> | <code>st1</code> |
     * <code>sc1</code>| <code>standard</code>)</p> </li> </ul>
     */
    inline bool FiltersHasBeenSet() const { return m_filtersHasBeenSet; }

    /**
     * <p>The filters.</p> <ul> <li> <p> <code>attachment.attach-time</code> - The time
     * stamp when the attachment initiated.</p> </li> <li> <p>
     * <code>attachment.delete-on-termination</code> - Whether the volume is deleted on
     * instance termination.</p> </li> <li> <p> <code>attachment.device</code> - The
     * device name specified in the block device mapping (for example,
     * <code>/dev/sda1</code>).</p> </li> <li> <p> <code>attachment.instance-id</code>
     * - The ID of the instance the volume is attached to.</p> </li> <li> <p>
     * <code>attachment.status</code> - The attachment state (<code>attaching</code> |
     * <code>attached</code> | <code>detaching</code>).</p> </li> <li> <p>
     * <code>availability-zone</code> - The Availability Zone in which the volume was
     * created.</p> </li> <li> <p> <code>create-time</code> - The time stamp when the
     * volume was created.</p> </li> <li> <p> <code>encrypted</code> - Indicates
     * whether the volume is encrypted (<code>true</code> | <code>false</code>)</p>
     * </li> <li> <p> <code>multi-attach-enabled</code> - Indicates whether the volume
     * is enabled for Multi-Attach (<code>true</code> | <code>false</code>)</p> </li>
     * <li> <p> <code>fast-restored</code> - Indicates whether the volume was created
     * from a snapshot that is enabled for fast snapshot restore (<code>true</code> |
     * <code>false</code>).</p> </li> <li> <p> <code>size</code> - The size of the
     * volume, in GiB.</p> </li> <li> <p> <code>snapshot-id</code> - The snapshot from
     * which the volume was created.</p> </li> <li> <p> <code>status</code> - The state
     * of the volume (<code>creating</code> | <code>available</code> |
     * <code>in-use</code> | <code>deleting</code> | <code>deleted</code> |
     * <code>error</code>).</p> </li> <li> <p> <code>tag</code>:&lt;key&gt; - The
     * key/value combination of a tag assigned to the resource. Use the tag key in the
     * filter name and the tag value as the filter value. For example, to find all
     * resources that have a tag with the key <code>Owner</code> and the value
     * <code>TeamA</code>, specify <code>tag:Owner</code> for the filter name and
     * <code>TeamA</code> for the filter value.</p> </li> <li> <p> <code>tag-key</code>
     * - The key of a tag assigned to the resource. Use this filter to find all
     * resources assigned a tag with a specific key, regardless of the tag value.</p>
     * </li> <li> <p> <code>volume-id</code> - The volume ID.</p> </li> <li> <p>
     * <code>volume-type</code> - The Amazon EBS volume type (<code>gp2</code> |
     * <code>gp3</code> | <code>io1</code> | <code>io2</code> | <code>st1</code> |
     * <code>sc1</code>| <code>standard</code>)</p> </li> </ul>
     */
    inline void SetFilters(const Aws::Vector<Filter>& value) { m_filtersHasBeenSet = true; m_filters = value; }

    /**
     * <p>The filters.</p> <ul> <li> <p> <code>attachment.attach-time</code> - The time
     * stamp when the attachment initiated.</p> </li> <li> <p>
     * <code>attachment.delete-on-termination</code> - Whether the volume is deleted on
     * instance termination.</p> </li> <li> <p> <code>attachment.device</code> - The
     * device name specified in the block device mapping (for example,
     * <code>/dev/sda1</code>).</p> </li> <li> <p> <code>attachment.instance-id</code>
     * - The ID of the instance the volume is attached to.</p> </li> <li> <p>
     * <code>attachment.status</code> - The attachment state (<code>attaching</code> |
     * <code>attached</code> | <code>detaching</code>).</p> </li> <li> <p>
     * <code>availability-zone</code> - The Availability Zone in which the volume was
     * created.</p> </li> <li> <p> <code>create-time</code> - The time stamp when the
     * volume was created.</p> </li> <li> <p> <code>encrypted</code> - Indicates
     * whether the volume is encrypted (<code>true</code> | <code>false</code>)</p>
     * </li> <li> <p> <code>multi-attach-enabled</code> - Indicates whether the volume
     * is enabled for Multi-Attach (<code>true</code> | <code>false</code>)</p> </li>
     * <li> <p> <code>fast-restored</code> - Indicates whether the volume was created
     * from a snapshot that is enabled for fast snapshot restore (<code>true</code> |
     * <code>false</code>).</p> </li> <li> <p> <code>size</code> - The size of the
     * volume, in GiB.</p> </li> <li> <p> <code>snapshot-id</code> - The snapshot from
     * which the volume was created.</p> </li> <li> <p> <code>status</code> - The state
     * of the volume (<code>creating</code> | <code>available</code> |
     * <code>in-use</code> | <code>deleting</code> | <code>deleted</code> |
     * <code>error</code>).</p> </li> <li> <p> <code>tag</code>:&lt;key&gt; - The
     * key/value combination of a tag assigned to the resource. Use the tag key in the
     * filter name and the tag value as the filter value. For example, to find all
     * resources that have a tag with the key <code>Owner</code> and the value
     * <code>TeamA</code>, specify <code>tag:Owner</code> for the filter name and
     * <code>TeamA</code> for the filter value.</p> </li> <li> <p> <code>tag-key</code>
     * - The key of a tag assigned to the resource. Use this filter to find all
     * resources assigned a tag with a specific key, regardless of the tag value.</p>
     * </li> <li> <p> <code>volume-id</code> - The volume ID.</p> </li> <li> <p>
     * <code>volume-type</code> - The Amazon EBS volume type (<code>gp2</code> |
     * <code>gp3</code> | <code>io1</code> | <code>io2</code> | <code>st1</code> |
     * <code>sc1</code>| <code>standard</code>)</p> </li> </ul>
     */
    inline void SetFilters(Aws::Vector<Filter>&& value) { m_filtersHasBeenSet = true; m_filters = std::move(value); }

    /**
     * <p>The filters.</p> <ul> <li> <p> <code>attachment.attach-time</code> - The time
     * stamp when the attachment initiated.</p> </li> <li> <p>
     * <code>attachment.delete-on-termination</code> - Whether the volume is deleted on
     * instance termination.</p> </li> <li> <p> <code>attachment.device</code> - The
     * device name specified in the block device mapping (for example,
     * <code>/dev/sda1</code>).</p> </li> <li> <p> <code>attachment.instance-id</code>
     * - The ID of the instance the volume is attached to.</p> </li> <li> <p>
     * <code>attachment.status</code> - The attachment state (<code>attaching</code> |
     * <code>attached</code> | <code>detaching</code>).</p> </li> <li> <p>
     * <code>availability-zone</code> - The Availability Zone in which the volume was
     * created.</p> </li> <li> <p> <code>create-time</code> - The time stamp when the
     * volume was created.</p> </li> <li> <p> <code>encrypted</code> - Indicates
     * whether the volume is encrypted (<code>true</code> | <code>false</code>)</p>
     * </li> <li> <p> <code>multi-attach-enabled</code> - Indicates whether the volume
     * is enabled for Multi-Attach (<code>true</code> | <code>false</code>)</p> </li>
     * <li> <p> <code>fast-restored</code> - Indicates whether the volume was created
     * from a snapshot that is enabled for fast snapshot restore (<code>true</code> |
     * <code>false</code>).</p> </li> <li> <p> <code>size</code> - The size of the
     * volume, in GiB.</p> </li> <li> <p> <code>snapshot-id</code> - The snapshot from
     * which the volume was created.</p> </li> <li> <p> <code>status</code> - The state
     * of the volume (<code>creating</code> | <code>available</code> |
     * <code>in-use</code> | <code>deleting</code> | <code>deleted</code> |
     * <code>error</code>).</p> </li> <li> <p> <code>tag</code>:&lt;key&gt; - The
     * key/value combination of a tag assigned to the resource. Use the tag key in the
     * filter name and the tag value as the filter value. For example, to find all
     * resources that have a tag with the key <code>Owner</code> and the value
     * <code>TeamA</code>, specify <code>tag:Owner</code> for the filter name and
     * <code>TeamA</code> for the filter value.</p> </li> <li> <p> <code>tag-key</code>
     * - The key of a tag assigned to the resource. Use this filter to find all
     * resources assigned a tag with a specific key, regardless of the tag value.</p>
     * </li> <li> <p> <code>volume-id</code> - The volume ID.</p> </li> <li> <p>
     * <code>volume-type</code> - The Amazon EBS volume type (<code>gp2</code> |
     * <code>gp3</code> | <code>io1</code> | <code>io2</code> | <code>st1</code> |
     * <code>sc1</code>| <code>standard</code>)</p> </li> </ul>
     */
    inline DescribeVolumesRequest& WithFilters(const Aws::Vector<Filter>& value) { SetFilters(value); return *this;}

    /**
     * <p>The filters.</p> <ul> <li> <p> <code>attachment.attach-time</code> - The time
     * stamp when the attachment initiated.</p> </li> <li> <p>
     * <code>attachment.delete-on-termination</code> - Whether the volume is deleted on
     * instance termination.</p> </li> <li> <p> <code>attachment.device</code> - The
     * device name specified in the block device mapping (for example,
     * <code>/dev/sda1</code>).</p> </li> <li> <p> <code>attachment.instance-id</code>
     * - The ID of the instance the volume is attached to.</p> </li> <li> <p>
     * <code>attachment.status</code> - The attachment state (<code>attaching</code> |
     * <code>attached</code> | <code>detaching</code>).</p> </li> <li> <p>
     * <code>availability-zone</code> - The Availability Zone in which the volume was
     * created.</p> </li> <li> <p> <code>create-time</code> - The time stamp when the
     * volume was created.</p> </li> <li> <p> <code>encrypted</code> - Indicates
     * whether the volume is encrypted (<code>true</code> | <code>false</code>)</p>
     * </li> <li> <p> <code>multi-attach-enabled</code> - Indicates whether the volume
     * is enabled for Multi-Attach (<code>true</code> | <code>false</code>)</p> </li>
     * <li> <p> <code>fast-restored</code> - Indicates whether the volume was created
     * from a snapshot that is enabled for fast snapshot restore (<code>true</code> |
     * <code>false</code>).</p> </li> <li> <p> <code>size</code> - The size of the
     * volume, in GiB.</p> </li> <li> <p> <code>snapshot-id</code> - The snapshot from
     * which the volume was created.</p> </li> <li> <p> <code>status</code> - The state
     * of the volume (<code>creating</code> | <code>available</code> |
     * <code>in-use</code> | <code>deleting</code> | <code>deleted</code> |
     * <code>error</code>).</p> </li> <li> <p> <code>tag</code>:&lt;key&gt; - The
     * key/value combination of a tag assigned to the resource. Use the tag key in the
     * filter name and the tag value as the filter value. For example, to find all
     * resources that have a tag with the key <code>Owner</code> and the value
     * <code>TeamA</code>, specify <code>tag:Owner</code> for the filter name and
     * <code>TeamA</code> for the filter value.</p> </li> <li> <p> <code>tag-key</code>
     * - The key of a tag assigned to the resource. Use this filter to find all
     * resources assigned a tag with a specific key, regardless of the tag value.</p>
     * </li> <li> <p> <code>volume-id</code> - The volume ID.</p> </li> <li> <p>
     * <code>volume-type</code> - The Amazon EBS volume type (<code>gp2</code> |
     * <code>gp3</code> | <code>io1</code> | <code>io2</code> | <code>st1</code> |
     * <code>sc1</code>| <code>standard</code>)</p> </li> </ul>
     */
    inline DescribeVolumesRequest& WithFilters(Aws::Vector<Filter>&& value) { SetFilters(std::move(value)); return *this;}

    /**
     * <p>The filters.</p> <ul> <li> <p> <code>attachment.attach-time</code> - The time
     * stamp when the attachment initiated.</p> </li> <li> <p>
     * <code>attachment.delete-on-termination</code> - Whether the volume is deleted on
     * instance termination.</p> </li> <li> <p> <code>attachment.device</code> - The
     * device name specified in the block device mapping (for example,
     * <code>/dev/sda1</code>).</p> </li> <li> <p> <code>attachment.instance-id</code>
     * - The ID of the instance the volume is attached to.</p> </li> <li> <p>
     * <code>attachment.status</code> - The attachment state (<code>attaching</code> |
     * <code>attached</code> | <code>detaching</code>).</p> </li> <li> <p>
     * <code>availability-zone</code> - The Availability Zone in which the volume was
     * created.</p> </li> <li> <p> <code>create-time</code> - The time stamp when the
     * volume was created.</p> </li> <li> <p> <code>encrypted</code> - Indicates
     * whether the volume is encrypted (<code>true</code> | <code>false</code>)</p>
     * </li> <li> <p> <code>multi-attach-enabled</code> - Indicates whether the volume
     * is enabled for Multi-Attach (<code>true</code> | <code>false</code>)</p> </li>
     * <li> <p> <code>fast-restored</code> - Indicates whether the volume was created
     * from a snapshot that is enabled for fast snapshot restore (<code>true</code> |
     * <code>false</code>).</p> </li> <li> <p> <code>size</code> - The size of the
     * volume, in GiB.</p> </li> <li> <p> <code>snapshot-id</code> - The snapshot from
     * which the volume was created.</p> </li> <li> <p> <code>status</code> - The state
     * of the volume (<code>creating</code> | <code>available</code> |
     * <code>in-use</code> | <code>deleting</code> | <code>deleted</code> |
     * <code>error</code>).</p> </li> <li> <p> <code>tag</code>:&lt;key&gt; - The
     * key/value combination of a tag assigned to the resource. Use the tag key in the
     * filter name and the tag value as the filter value. For example, to find all
     * resources that have a tag with the key <code>Owner</code> and the value
     * <code>TeamA</code>, specify <code>tag:Owner</code> for the filter name and
     * <code>TeamA</code> for the filter value.</p> </li> <li> <p> <code>tag-key</code>
     * - The key of a tag assigned to the resource. Use this filter to find all
     * resources assigned a tag with a specific key, regardless of the tag value.</p>
     * </li> <li> <p> <code>volume-id</code> - The volume ID.</p> </li> <li> <p>
     * <code>volume-type</code> - The Amazon EBS volume type (<code>gp2</code> |
     * <code>gp3</code> | <code>io1</code> | <code>io2</code> | <code>st1</code> |
     * <code>sc1</code>| <code>standard</code>)</p> </li> </ul>
     */
    inline DescribeVolumesRequest& AddFilters(const Filter& value) { m_filtersHasBeenSet = true; m_filters.push_back(value); return *this; }

    /**
     * <p>The filters.</p> <ul> <li> <p> <code>attachment.attach-time</code> - The time
     * stamp when the attachment initiated.</p> </li> <li> <p>
     * <code>attachment.delete-on-termination</code> - Whether the volume is deleted on
     * instance termination.</p> </li> <li> <p> <code>attachment.device</code> - The
     * device name specified in the block device mapping (for example,
     * <code>/dev/sda1</code>).</p> </li> <li> <p> <code>attachment.instance-id</code>
     * - The ID of the instance the volume is attached to.</p> </li> <li> <p>
     * <code>attachment.status</code> - The attachment state (<code>attaching</code> |
     * <code>attached</code> | <code>detaching</code>).</p> </li> <li> <p>
     * <code>availability-zone</code> - The Availability Zone in which the volume was
     * created.</p> </li> <li> <p> <code>create-time</code> - The time stamp when the
     * volume was created.</p> </li> <li> <p> <code>encrypted</code> - Indicates
     * whether the volume is encrypted (<code>true</code> | <code>false</code>)</p>
     * </li> <li> <p> <code>multi-attach-enabled</code> - Indicates whether the volume
     * is enabled for Multi-Attach (<code>true</code> | <code>false</code>)</p> </li>
     * <li> <p> <code>fast-restored</code> - Indicates whether the volume was created
     * from a snapshot that is enabled for fast snapshot restore (<code>true</code> |
     * <code>false</code>).</p> </li> <li> <p> <code>size</code> - The size of the
     * volume, in GiB.</p> </li> <li> <p> <code>snapshot-id</code> - The snapshot from
     * which the volume was created.</p> </li> <li> <p> <code>status</code> - The state
     * of the volume (<code>creating</code> | <code>available</code> |
     * <code>in-use</code> | <code>deleting</code> | <code>deleted</code> |
     * <code>error</code>).</p> </li> <li> <p> <code>tag</code>:&lt;key&gt; - The
     * key/value combination of a tag assigned to the resource. Use the tag key in the
     * filter name and the tag value as the filter value. For example, to find all
     * resources that have a tag with the key <code>Owner</code> and the value
     * <code>TeamA</code>, specify <code>tag:Owner</code> for the filter name and
     * <code>TeamA</code> for the filter value.</p> </li> <li> <p> <code>tag-key</code>
     * - The key of a tag assigned to the resource. Use this filter to find all
     * resources assigned a tag with a specific key, regardless of the tag value.</p>
     * </li> <li> <p> <code>volume-id</code> - The volume ID.</p> </li> <li> <p>
     * <code>volume-type</code> - The Amazon EBS volume type (<code>gp2</code> |
     * <code>gp3</code> | <code>io1</code> | <code>io2</code> | <code>st1</code> |
     * <code>sc1</code>| <code>standard</code>)</p> </li> </ul>
     */
    inline DescribeVolumesRequest& AddFilters(Filter&& value) { m_filtersHasBeenSet = true; m_filters.push_back(std::move(value)); return *this; }


    /**
     * <p>The volume IDs.</p>
     */
    inline const Aws::Vector<Aws::String>& GetVolumeIds() const{ return m_volumeIds; }

    /**
     * <p>The volume IDs.</p>
     */
    inline bool VolumeIdsHasBeenSet() const { return m_volumeIdsHasBeenSet; }

    /**
     * <p>The volume IDs.</p>
     */
    inline void SetVolumeIds(const Aws::Vector<Aws::String>& value) { m_volumeIdsHasBeenSet = true; m_volumeIds = value; }

    /**
     * <p>The volume IDs.</p>
     */
    inline void SetVolumeIds(Aws::Vector<Aws::String>&& value) { m_volumeIdsHasBeenSet = true; m_volumeIds = std::move(value); }

    /**
     * <p>The volume IDs.</p>
     */
    inline DescribeVolumesRequest& WithVolumeIds(const Aws::Vector<Aws::String>& value) { SetVolumeIds(value); return *this;}

    /**
     * <p>The volume IDs.</p>
     */
    inline DescribeVolumesRequest& WithVolumeIds(Aws::Vector<Aws::String>&& value) { SetVolumeIds(std::move(value)); return *this;}

    /**
     * <p>The volume IDs.</p>
     */
    inline DescribeVolumesRequest& AddVolumeIds(const Aws::String& value) { m_volumeIdsHasBeenSet = true; m_volumeIds.push_back(value); return *this; }

    /**
     * <p>The volume IDs.</p>
     */
    inline DescribeVolumesRequest& AddVolumeIds(Aws::String&& value) { m_volumeIdsHasBeenSet = true; m_volumeIds.push_back(std::move(value)); return *this; }

    /**
     * <p>The volume IDs.</p>
     */
    inline DescribeVolumesRequest& AddVolumeIds(const char* value) { m_volumeIdsHasBeenSet = true; m_volumeIds.push_back(value); return *this; }


    /**
     * <p>Checks whether you have the required permissions for the action, without
     * actually making the request, and provides an error response. If you have the
     * required permissions, the error response is <code>DryRunOperation</code>.
     * Otherwise, it is <code>UnauthorizedOperation</code>.</p>
     */
    inline bool GetDryRun() const{ return m_dryRun; }

    /**
     * <p>Checks whether you have the required permissions for the action, without
     * actually making the request, and provides an error response. If you have the
     * required permissions, the error response is <code>DryRunOperation</code>.
     * Otherwise, it is <code>UnauthorizedOperation</code>.</p>
     */
    inline bool DryRunHasBeenSet() const { return m_dryRunHasBeenSet; }

    /**
     * <p>Checks whether you have the required permissions for the action, without
     * actually making the request, and provides an error response. If you have the
     * required permissions, the error response is <code>DryRunOperation</code>.
     * Otherwise, it is <code>UnauthorizedOperation</code>.</p>
     */
    inline void SetDryRun(bool value) { m_dryRunHasBeenSet = true; m_dryRun = value; }

    /**
     * <p>Checks whether you have the required permissions for the action, without
     * actually making the request, and provides an error response. If you have the
     * required permissions, the error response is <code>DryRunOperation</code>.
     * Otherwise, it is <code>UnauthorizedOperation</code>.</p>
     */
    inline DescribeVolumesRequest& WithDryRun(bool value) { SetDryRun(value); return *this;}


    /**
     * <p>The maximum number of volumes to return for this request. This value can be
     * between 5 and 500; if you specify a value larger than 500, only 500 items are
     * returned. If this parameter is not used, then all items are returned. You cannot
     * specify this parameter and the volume IDs parameter in the same request. For
     * more information, see <a
     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination">Pagination</a>.</p>
     */
    inline int GetMaxResults() const{ return m_maxResults; }

    /**
     * <p>The maximum number of volumes to return for this request. This value can be
     * between 5 and 500; if you specify a value larger than 500, only 500 items are
     * returned. If this parameter is not used, then all items are returned. You cannot
     * specify this parameter and the volume IDs parameter in the same request. For
     * more information, see <a
     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination">Pagination</a>.</p>
     */
    inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }

    /**
     * <p>The maximum number of volumes to return for this request. This value can be
     * between 5 and 500; if you specify a value larger than 500, only 500 items are
     * returned. If this parameter is not used, then all items are returned. You cannot
     * specify this parameter and the volume IDs parameter in the same request. For
     * more information, see <a
     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination">Pagination</a>.</p>
     */
    inline void SetMaxResults(int value) { m_maxResultsHasBeenSet = true; m_maxResults = value; }

    /**
     * <p>The maximum number of volumes to return for this request. This value can be
     * between 5 and 500; if you specify a value larger than 500, only 500 items are
     * returned. If this parameter is not used, then all items are returned. You cannot
     * specify this parameter and the volume IDs parameter in the same request. For
     * more information, see <a
     * href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination">Pagination</a>.</p>
     */
    inline DescribeVolumesRequest& WithMaxResults(int value) { SetMaxResults(value); return *this;}


    /**
     * <p>The token returned from a previous paginated request. Pagination continues
     * from the end of the items returned from the previous request.</p>
     */
    inline const Aws::String& GetNextToken() const{ return m_nextToken; }

    /**
     * <p>The token returned from a previous paginated request. Pagination continues
     * from the end of the items returned from the previous request.</p>
     */
    inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }

    /**
     * <p>The token returned from a previous paginated request. Pagination continues
     * from the end of the items returned from the previous request.</p>
     */
    inline void SetNextToken(const Aws::String& value) { m_nextTokenHasBeenSet = true; m_nextToken = value; }

    /**
     * <p>The token returned from a previous paginated request. Pagination continues
     * from the end of the items returned from the previous request.</p>
     */
    inline void SetNextToken(Aws::String&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::move(value); }

    /**
     * <p>The token returned from a previous paginated request. Pagination continues
     * from the end of the items returned from the previous request.</p>
     */
    inline void SetNextToken(const char* value) { m_nextTokenHasBeenSet = true; m_nextToken.assign(value); }

    /**
     * <p>The token returned from a previous paginated request. Pagination continues
     * from the end of the items returned from the previous request.</p>
     */
    inline DescribeVolumesRequest& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}

    /**
     * <p>The token returned from a previous paginated request. Pagination continues
     * from the end of the items returned from the previous request.</p>
     */
    inline DescribeVolumesRequest& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}

    /**
     * <p>The token returned from a previous paginated request. Pagination continues
     * from the end of the items returned from the previous request.</p>
     */
    inline DescribeVolumesRequest& WithNextToken(const char* value) { SetNextToken(value); return *this;}

  private:

    Aws::Vector<Filter> m_filters;
    bool m_filtersHasBeenSet = false;

    Aws::Vector<Aws::String> m_volumeIds;
    bool m_volumeIdsHasBeenSet = false;

    bool m_dryRun;
    bool m_dryRunHasBeenSet = false;

    int m_maxResults;
    bool m_maxResultsHasBeenSet = false;

    Aws::String m_nextToken;
    bool m_nextTokenHasBeenSet = false;
  };

} // namespace Model
} // namespace EC2
} // namespace Aws
