﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/mq/MQ_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace MQ
{
namespace Model
{

  /**
   * <p>Specifies a broker in a data replication pair.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/mq-2017-11-27/DataReplicationCounterpart">AWS
   * API Reference</a></p>
   */
  class DataReplicationCounterpart
  {
  public:
    AWS_MQ_API DataReplicationCounterpart();
    AWS_MQ_API DataReplicationCounterpart(Aws::Utils::Json::JsonView jsonValue);
    AWS_MQ_API DataReplicationCounterpart& operator=(Aws::Utils::Json::JsonView jsonValue);
    AWS_MQ_API Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>Required. The unique broker id generated by Amazon MQ.</p>
     */
    inline const Aws::String& GetBrokerId() const{ return m_brokerId; }

    /**
     * <p>Required. The unique broker id generated by Amazon MQ.</p>
     */
    inline bool BrokerIdHasBeenSet() const { return m_brokerIdHasBeenSet; }

    /**
     * <p>Required. The unique broker id generated by Amazon MQ.</p>
     */
    inline void SetBrokerId(const Aws::String& value) { m_brokerIdHasBeenSet = true; m_brokerId = value; }

    /**
     * <p>Required. The unique broker id generated by Amazon MQ.</p>
     */
    inline void SetBrokerId(Aws::String&& value) { m_brokerIdHasBeenSet = true; m_brokerId = std::move(value); }

    /**
     * <p>Required. The unique broker id generated by Amazon MQ.</p>
     */
    inline void SetBrokerId(const char* value) { m_brokerIdHasBeenSet = true; m_brokerId.assign(value); }

    /**
     * <p>Required. The unique broker id generated by Amazon MQ.</p>
     */
    inline DataReplicationCounterpart& WithBrokerId(const Aws::String& value) { SetBrokerId(value); return *this;}

    /**
     * <p>Required. The unique broker id generated by Amazon MQ.</p>
     */
    inline DataReplicationCounterpart& WithBrokerId(Aws::String&& value) { SetBrokerId(std::move(value)); return *this;}

    /**
     * <p>Required. The unique broker id generated by Amazon MQ.</p>
     */
    inline DataReplicationCounterpart& WithBrokerId(const char* value) { SetBrokerId(value); return *this;}


    /**
     * <p>Required. The region of the broker.</p>
     */
    inline const Aws::String& GetRegion() const{ return m_region; }

    /**
     * <p>Required. The region of the broker.</p>
     */
    inline bool RegionHasBeenSet() const { return m_regionHasBeenSet; }

    /**
     * <p>Required. The region of the broker.</p>
     */
    inline void SetRegion(const Aws::String& value) { m_regionHasBeenSet = true; m_region = value; }

    /**
     * <p>Required. The region of the broker.</p>
     */
    inline void SetRegion(Aws::String&& value) { m_regionHasBeenSet = true; m_region = std::move(value); }

    /**
     * <p>Required. The region of the broker.</p>
     */
    inline void SetRegion(const char* value) { m_regionHasBeenSet = true; m_region.assign(value); }

    /**
     * <p>Required. The region of the broker.</p>
     */
    inline DataReplicationCounterpart& WithRegion(const Aws::String& value) { SetRegion(value); return *this;}

    /**
     * <p>Required. The region of the broker.</p>
     */
    inline DataReplicationCounterpart& WithRegion(Aws::String&& value) { SetRegion(std::move(value)); return *this;}

    /**
     * <p>Required. The region of the broker.</p>
     */
    inline DataReplicationCounterpart& WithRegion(const char* value) { SetRegion(value); return *this;}

  private:

    Aws::String m_brokerId;
    bool m_brokerIdHasBeenSet = false;

    Aws::String m_region;
    bool m_regionHasBeenSet = false;
  };

} // namespace Model
} // namespace MQ
} // namespace Aws
