﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/quicksight/QuickSight_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <aws/quicksight/QuickSightEndpointRules.h>


namespace Aws
{
namespace QuickSight
{
namespace Endpoint
{
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::EndpointProviderBase;
using Aws::Endpoint::DefaultEndpointProvider;

using QuickSightClientContextParameters = Aws::Endpoint::ClientContextParameters;

using QuickSightClientConfiguration = Aws::Client::GenericClientConfiguration<false>;
using QuickSightBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the QuickSight Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using QuickSightEndpointProviderBase =
    EndpointProviderBase<QuickSightClientConfiguration, QuickSightBuiltInParameters, QuickSightClientContextParameters>;

using QuickSightDefaultEpProviderBase =
    DefaultEndpointProvider<QuickSightClientConfiguration, QuickSightBuiltInParameters, QuickSightClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_QUICKSIGHT_API QuickSightEndpointProvider : public QuickSightDefaultEpProviderBase
{
public:
    using QuickSightResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

    QuickSightEndpointProvider()
      : QuickSightDefaultEpProviderBase(Aws::QuickSight::QuickSightEndpointRules::GetRulesBlob(), Aws::QuickSight::QuickSightEndpointRules::RulesBlobSize)
    {}

    ~QuickSightEndpointProvider()
    {
    }
};
} // namespace Endpoint
} // namespace QuickSight
} // namespace Aws
