﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/rekognition/Rekognition_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace Rekognition
{
namespace Model
{

  /**
   * <p>Contains settings that specify the location of an Amazon S3 bucket used to
   * store the output of a Face Liveness session. Note that the S3 bucket must be
   * located in the caller's AWS account and in the same region as the Face Liveness
   * end-point. Additionally, the Amazon S3 object keys are auto-generated by the
   * Face Liveness system. </p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/rekognition-2016-06-27/LivenessOutputConfig">AWS
   * API Reference</a></p>
   */
  class LivenessOutputConfig
  {
  public:
    AWS_REKOGNITION_API LivenessOutputConfig();
    AWS_REKOGNITION_API LivenessOutputConfig(Aws::Utils::Json::JsonView jsonValue);
    AWS_REKOGNITION_API LivenessOutputConfig& operator=(Aws::Utils::Json::JsonView jsonValue);
    AWS_REKOGNITION_API Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>The path to an AWS Amazon S3 bucket used to store Face Liveness session
     * results.</p>
     */
    inline const Aws::String& GetS3Bucket() const{ return m_s3Bucket; }

    /**
     * <p>The path to an AWS Amazon S3 bucket used to store Face Liveness session
     * results.</p>
     */
    inline bool S3BucketHasBeenSet() const { return m_s3BucketHasBeenSet; }

    /**
     * <p>The path to an AWS Amazon S3 bucket used to store Face Liveness session
     * results.</p>
     */
    inline void SetS3Bucket(const Aws::String& value) { m_s3BucketHasBeenSet = true; m_s3Bucket = value; }

    /**
     * <p>The path to an AWS Amazon S3 bucket used to store Face Liveness session
     * results.</p>
     */
    inline void SetS3Bucket(Aws::String&& value) { m_s3BucketHasBeenSet = true; m_s3Bucket = std::move(value); }

    /**
     * <p>The path to an AWS Amazon S3 bucket used to store Face Liveness session
     * results.</p>
     */
    inline void SetS3Bucket(const char* value) { m_s3BucketHasBeenSet = true; m_s3Bucket.assign(value); }

    /**
     * <p>The path to an AWS Amazon S3 bucket used to store Face Liveness session
     * results.</p>
     */
    inline LivenessOutputConfig& WithS3Bucket(const Aws::String& value) { SetS3Bucket(value); return *this;}

    /**
     * <p>The path to an AWS Amazon S3 bucket used to store Face Liveness session
     * results.</p>
     */
    inline LivenessOutputConfig& WithS3Bucket(Aws::String&& value) { SetS3Bucket(std::move(value)); return *this;}

    /**
     * <p>The path to an AWS Amazon S3 bucket used to store Face Liveness session
     * results.</p>
     */
    inline LivenessOutputConfig& WithS3Bucket(const char* value) { SetS3Bucket(value); return *this;}


    /**
     * <p>The prefix prepended to the output files for the Face Liveness session
     * results.</p>
     */
    inline const Aws::String& GetS3KeyPrefix() const{ return m_s3KeyPrefix; }

    /**
     * <p>The prefix prepended to the output files for the Face Liveness session
     * results.</p>
     */
    inline bool S3KeyPrefixHasBeenSet() const { return m_s3KeyPrefixHasBeenSet; }

    /**
     * <p>The prefix prepended to the output files for the Face Liveness session
     * results.</p>
     */
    inline void SetS3KeyPrefix(const Aws::String& value) { m_s3KeyPrefixHasBeenSet = true; m_s3KeyPrefix = value; }

    /**
     * <p>The prefix prepended to the output files for the Face Liveness session
     * results.</p>
     */
    inline void SetS3KeyPrefix(Aws::String&& value) { m_s3KeyPrefixHasBeenSet = true; m_s3KeyPrefix = std::move(value); }

    /**
     * <p>The prefix prepended to the output files for the Face Liveness session
     * results.</p>
     */
    inline void SetS3KeyPrefix(const char* value) { m_s3KeyPrefixHasBeenSet = true; m_s3KeyPrefix.assign(value); }

    /**
     * <p>The prefix prepended to the output files for the Face Liveness session
     * results.</p>
     */
    inline LivenessOutputConfig& WithS3KeyPrefix(const Aws::String& value) { SetS3KeyPrefix(value); return *this;}

    /**
     * <p>The prefix prepended to the output files for the Face Liveness session
     * results.</p>
     */
    inline LivenessOutputConfig& WithS3KeyPrefix(Aws::String&& value) { SetS3KeyPrefix(std::move(value)); return *this;}

    /**
     * <p>The prefix prepended to the output files for the Face Liveness session
     * results.</p>
     */
    inline LivenessOutputConfig& WithS3KeyPrefix(const char* value) { SetS3KeyPrefix(value); return *this;}

  private:

    Aws::String m_s3Bucket;
    bool m_s3BucketHasBeenSet = false;

    Aws::String m_s3KeyPrefix;
    bool m_s3KeyPrefixHasBeenSet = false;
  };

} // namespace Model
} // namespace Rekognition
} // namespace Aws
