﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/sms/SMS_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <aws/sms/SMSEndpointRules.h>


namespace Aws
{
namespace SMS
{
namespace Endpoint
{
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::EndpointProviderBase;
using Aws::Endpoint::DefaultEndpointProvider;

using SMSClientContextParameters = Aws::Endpoint::ClientContextParameters;

using SMSClientConfiguration = Aws::Client::GenericClientConfiguration<false>;
using SMSBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the SMS Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using SMSEndpointProviderBase =
    EndpointProviderBase<SMSClientConfiguration, SMSBuiltInParameters, SMSClientContextParameters>;

using SMSDefaultEpProviderBase =
    DefaultEndpointProvider<SMSClientConfiguration, SMSBuiltInParameters, SMSClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_SMS_API SMSEndpointProvider : public SMSDefaultEpProviderBase
{
public:
    using SMSResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

    SMSEndpointProvider()
      : SMSDefaultEpProviderBase(Aws::SMS::SMSEndpointRules::GetRulesBlob(), Aws::SMS::SMSEndpointRules::RulesBlobSize)
    {}

    ~SMSEndpointProvider()
    {
    }
};
} // namespace Endpoint
} // namespace SMS
} // namespace Aws
