﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/swf/SWF_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
template<typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils
{
namespace Json
{
  class JsonValue;
} // namespace Json
} // namespace Utils
namespace SWF
{
namespace Model
{
  /**
   * <p>Specifies the <code>runId</code> of a workflow execution.</p><p><h3>See
   * Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/swf-2012-01-25/Run">AWS API
   * Reference</a></p>
   */
  class StartWorkflowExecutionResult
  {
  public:
    AWS_SWF_API StartWorkflowExecutionResult();
    AWS_SWF_API StartWorkflowExecutionResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
    AWS_SWF_API StartWorkflowExecutionResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);


    /**
     * <p>The <code>runId</code> of a workflow execution. This ID is generated by the
     * service and can be used to uniquely identify the workflow execution within a
     * domain.</p>
     */
    inline const Aws::String& GetRunId() const{ return m_runId; }

    /**
     * <p>The <code>runId</code> of a workflow execution. This ID is generated by the
     * service and can be used to uniquely identify the workflow execution within a
     * domain.</p>
     */
    inline void SetRunId(const Aws::String& value) { m_runId = value; }

    /**
     * <p>The <code>runId</code> of a workflow execution. This ID is generated by the
     * service and can be used to uniquely identify the workflow execution within a
     * domain.</p>
     */
    inline void SetRunId(Aws::String&& value) { m_runId = std::move(value); }

    /**
     * <p>The <code>runId</code> of a workflow execution. This ID is generated by the
     * service and can be used to uniquely identify the workflow execution within a
     * domain.</p>
     */
    inline void SetRunId(const char* value) { m_runId.assign(value); }

    /**
     * <p>The <code>runId</code> of a workflow execution. This ID is generated by the
     * service and can be used to uniquely identify the workflow execution within a
     * domain.</p>
     */
    inline StartWorkflowExecutionResult& WithRunId(const Aws::String& value) { SetRunId(value); return *this;}

    /**
     * <p>The <code>runId</code> of a workflow execution. This ID is generated by the
     * service and can be used to uniquely identify the workflow execution within a
     * domain.</p>
     */
    inline StartWorkflowExecutionResult& WithRunId(Aws::String&& value) { SetRunId(std::move(value)); return *this;}

    /**
     * <p>The <code>runId</code> of a workflow execution. This ID is generated by the
     * service and can be used to uniquely identify the workflow execution within a
     * domain.</p>
     */
    inline StartWorkflowExecutionResult& WithRunId(const char* value) { SetRunId(value); return *this;}


    
    inline const Aws::String& GetRequestId() const{ return m_requestId; }

    
    inline void SetRequestId(const Aws::String& value) { m_requestId = value; }

    
    inline void SetRequestId(Aws::String&& value) { m_requestId = std::move(value); }

    
    inline void SetRequestId(const char* value) { m_requestId.assign(value); }

    
    inline StartWorkflowExecutionResult& WithRequestId(const Aws::String& value) { SetRequestId(value); return *this;}

    
    inline StartWorkflowExecutionResult& WithRequestId(Aws::String&& value) { SetRequestId(std::move(value)); return *this;}

    
    inline StartWorkflowExecutionResult& WithRequestId(const char* value) { SetRequestId(value); return *this;}

  private:

    Aws::String m_runId;

    Aws::String m_requestId;
  };

} // namespace Model
} // namespace SWF
} // namespace Aws
