﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/workmail/WorkMail_EXPORTS.h>
#include <aws/workmail/WorkMailRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace WorkMail
{
namespace Model
{

  /**
   */
  class RegisterToWorkMailRequest : public WorkMailRequest
  {
  public:
    AWS_WORKMAIL_API RegisterToWorkMailRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "RegisterToWorkMail"; }

    AWS_WORKMAIL_API Aws::String SerializePayload() const override;

    AWS_WORKMAIL_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;


    /**
     * <p>The identifier for the organization under which the user, group, or resource
     * exists.</p>
     */
    inline const Aws::String& GetOrganizationId() const{ return m_organizationId; }

    /**
     * <p>The identifier for the organization under which the user, group, or resource
     * exists.</p>
     */
    inline bool OrganizationIdHasBeenSet() const { return m_organizationIdHasBeenSet; }

    /**
     * <p>The identifier for the organization under which the user, group, or resource
     * exists.</p>
     */
    inline void SetOrganizationId(const Aws::String& value) { m_organizationIdHasBeenSet = true; m_organizationId = value; }

    /**
     * <p>The identifier for the organization under which the user, group, or resource
     * exists.</p>
     */
    inline void SetOrganizationId(Aws::String&& value) { m_organizationIdHasBeenSet = true; m_organizationId = std::move(value); }

    /**
     * <p>The identifier for the organization under which the user, group, or resource
     * exists.</p>
     */
    inline void SetOrganizationId(const char* value) { m_organizationIdHasBeenSet = true; m_organizationId.assign(value); }

    /**
     * <p>The identifier for the organization under which the user, group, or resource
     * exists.</p>
     */
    inline RegisterToWorkMailRequest& WithOrganizationId(const Aws::String& value) { SetOrganizationId(value); return *this;}

    /**
     * <p>The identifier for the organization under which the user, group, or resource
     * exists.</p>
     */
    inline RegisterToWorkMailRequest& WithOrganizationId(Aws::String&& value) { SetOrganizationId(std::move(value)); return *this;}

    /**
     * <p>The identifier for the organization under which the user, group, or resource
     * exists.</p>
     */
    inline RegisterToWorkMailRequest& WithOrganizationId(const char* value) { SetOrganizationId(value); return *this;}


    /**
     * <p>The identifier for the user, group, or resource to be updated.</p> <p>The
     * identifier can accept <i>UserId, ResourceId, or GroupId</i>, or <i>Username,
     * Resourcename, or Groupname</i>. The following identity formats are
     * available:</p> <ul> <li> <p>Entity ID: 12345678-1234-1234-1234-123456789012,
     * r-0123456789a0123456789b0123456789, or
     * S-1-1-12-1234567890-123456789-123456789-1234</p> </li> <li> <p>Entity name:
     * entity</p> </li> </ul>
     */
    inline const Aws::String& GetEntityId() const{ return m_entityId; }

    /**
     * <p>The identifier for the user, group, or resource to be updated.</p> <p>The
     * identifier can accept <i>UserId, ResourceId, or GroupId</i>, or <i>Username,
     * Resourcename, or Groupname</i>. The following identity formats are
     * available:</p> <ul> <li> <p>Entity ID: 12345678-1234-1234-1234-123456789012,
     * r-0123456789a0123456789b0123456789, or
     * S-1-1-12-1234567890-123456789-123456789-1234</p> </li> <li> <p>Entity name:
     * entity</p> </li> </ul>
     */
    inline bool EntityIdHasBeenSet() const { return m_entityIdHasBeenSet; }

    /**
     * <p>The identifier for the user, group, or resource to be updated.</p> <p>The
     * identifier can accept <i>UserId, ResourceId, or GroupId</i>, or <i>Username,
     * Resourcename, or Groupname</i>. The following identity formats are
     * available:</p> <ul> <li> <p>Entity ID: 12345678-1234-1234-1234-123456789012,
     * r-0123456789a0123456789b0123456789, or
     * S-1-1-12-1234567890-123456789-123456789-1234</p> </li> <li> <p>Entity name:
     * entity</p> </li> </ul>
     */
    inline void SetEntityId(const Aws::String& value) { m_entityIdHasBeenSet = true; m_entityId = value; }

    /**
     * <p>The identifier for the user, group, or resource to be updated.</p> <p>The
     * identifier can accept <i>UserId, ResourceId, or GroupId</i>, or <i>Username,
     * Resourcename, or Groupname</i>. The following identity formats are
     * available:</p> <ul> <li> <p>Entity ID: 12345678-1234-1234-1234-123456789012,
     * r-0123456789a0123456789b0123456789, or
     * S-1-1-12-1234567890-123456789-123456789-1234</p> </li> <li> <p>Entity name:
     * entity</p> </li> </ul>
     */
    inline void SetEntityId(Aws::String&& value) { m_entityIdHasBeenSet = true; m_entityId = std::move(value); }

    /**
     * <p>The identifier for the user, group, or resource to be updated.</p> <p>The
     * identifier can accept <i>UserId, ResourceId, or GroupId</i>, or <i>Username,
     * Resourcename, or Groupname</i>. The following identity formats are
     * available:</p> <ul> <li> <p>Entity ID: 12345678-1234-1234-1234-123456789012,
     * r-0123456789a0123456789b0123456789, or
     * S-1-1-12-1234567890-123456789-123456789-1234</p> </li> <li> <p>Entity name:
     * entity</p> </li> </ul>
     */
    inline void SetEntityId(const char* value) { m_entityIdHasBeenSet = true; m_entityId.assign(value); }

    /**
     * <p>The identifier for the user, group, or resource to be updated.</p> <p>The
     * identifier can accept <i>UserId, ResourceId, or GroupId</i>, or <i>Username,
     * Resourcename, or Groupname</i>. The following identity formats are
     * available:</p> <ul> <li> <p>Entity ID: 12345678-1234-1234-1234-123456789012,
     * r-0123456789a0123456789b0123456789, or
     * S-1-1-12-1234567890-123456789-123456789-1234</p> </li> <li> <p>Entity name:
     * entity</p> </li> </ul>
     */
    inline RegisterToWorkMailRequest& WithEntityId(const Aws::String& value) { SetEntityId(value); return *this;}

    /**
     * <p>The identifier for the user, group, or resource to be updated.</p> <p>The
     * identifier can accept <i>UserId, ResourceId, or GroupId</i>, or <i>Username,
     * Resourcename, or Groupname</i>. The following identity formats are
     * available:</p> <ul> <li> <p>Entity ID: 12345678-1234-1234-1234-123456789012,
     * r-0123456789a0123456789b0123456789, or
     * S-1-1-12-1234567890-123456789-123456789-1234</p> </li> <li> <p>Entity name:
     * entity</p> </li> </ul>
     */
    inline RegisterToWorkMailRequest& WithEntityId(Aws::String&& value) { SetEntityId(std::move(value)); return *this;}

    /**
     * <p>The identifier for the user, group, or resource to be updated.</p> <p>The
     * identifier can accept <i>UserId, ResourceId, or GroupId</i>, or <i>Username,
     * Resourcename, or Groupname</i>. The following identity formats are
     * available:</p> <ul> <li> <p>Entity ID: 12345678-1234-1234-1234-123456789012,
     * r-0123456789a0123456789b0123456789, or
     * S-1-1-12-1234567890-123456789-123456789-1234</p> </li> <li> <p>Entity name:
     * entity</p> </li> </ul>
     */
    inline RegisterToWorkMailRequest& WithEntityId(const char* value) { SetEntityId(value); return *this;}


    /**
     * <p>The email for the user, group, or resource to be updated.</p>
     */
    inline const Aws::String& GetEmail() const{ return m_email; }

    /**
     * <p>The email for the user, group, or resource to be updated.</p>
     */
    inline bool EmailHasBeenSet() const { return m_emailHasBeenSet; }

    /**
     * <p>The email for the user, group, or resource to be updated.</p>
     */
    inline void SetEmail(const Aws::String& value) { m_emailHasBeenSet = true; m_email = value; }

    /**
     * <p>The email for the user, group, or resource to be updated.</p>
     */
    inline void SetEmail(Aws::String&& value) { m_emailHasBeenSet = true; m_email = std::move(value); }

    /**
     * <p>The email for the user, group, or resource to be updated.</p>
     */
    inline void SetEmail(const char* value) { m_emailHasBeenSet = true; m_email.assign(value); }

    /**
     * <p>The email for the user, group, or resource to be updated.</p>
     */
    inline RegisterToWorkMailRequest& WithEmail(const Aws::String& value) { SetEmail(value); return *this;}

    /**
     * <p>The email for the user, group, or resource to be updated.</p>
     */
    inline RegisterToWorkMailRequest& WithEmail(Aws::String&& value) { SetEmail(std::move(value)); return *this;}

    /**
     * <p>The email for the user, group, or resource to be updated.</p>
     */
    inline RegisterToWorkMailRequest& WithEmail(const char* value) { SetEmail(value); return *this;}

  private:

    Aws::String m_organizationId;
    bool m_organizationIdHasBeenSet = false;

    Aws::String m_entityId;
    bool m_entityIdHasBeenSet = false;

    Aws::String m_email;
    bool m_emailHasBeenSet = false;
  };

} // namespace Model
} // namespace WorkMail
} // namespace Aws
